@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import math
 import random
+import re
 import warnings
 from abc import ABC, abstractmethod
 from itertools import groupby, zip_longest
@@ -29,7 +30,7 @@ __all__ = [
     'diff',
     'Interleave',
     'interleave',
-    'source_mediainfo',
+    'source_mediainfo', 'srcm',
     'Split',
     'split',
     'stack_compare', 'scomp',
@@ -827,7 +828,7 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
     try:
         from pymediainfo import MediaInfo  # type:ignore
     except ModuleNotFoundError as e:
-        raise DependencyNotFoundError(e)
+        raise DependencyNotFoundError(source_mediainfo, e)
 
     from pprint import pformat, pprint
 
@@ -848,12 +849,20 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
     mi = MediaInfo.parse(filepath)
     gtrack = mi.general_tracks[0].to_data()
     vtrack = mi.video_tracks[stream_idx].to_data()
-    atrack = mi.audio_tracks[stream_idx].to_data()
+
+    # Try to obtain the grouptag to save as the output name for vspreview comping, else fall back on filename.
+    # This may not be entirely accurate, but I gotta try something!
+    if "_lossless" in filename:
+        filename = "Filtered lossless"
+
+    group = re.match(r"\[[a-zA-Z\-\u4e00-\u9fff一-]+\]", filename)
+
+    if group:
+        group = group.group(0)  # type:ignore
 
     if print_mediainfo:
         pprint(gtrack, sort_dicts=False, width=120, compact=True)
         pprint(vtrack, sort_dicts=False, width=120, compact=True)
-        pprint(atrack, sort_dicts=False, width=120, compact=True)
 
     stream_size = vtrack.get("other_stream_size")
 
@@ -861,14 +870,16 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
         stream_size = stream_size[-1]
 
     prop_dict.update({
-        "encode_date": gtrack.get("encoded_date", fallback),
+        # Basic information
+        "encode_date": f"{gtrack.get('encoded_date', gtrack.get('file_last_modification_date', fallback)):.23}",
         "total_filesize": gtrack.get("other_file_size", [fallback])[-1],
         "v_filesize": stream_size or fallback,
+        # Format/writing information
         "v_bitdepth": vtrack.get("bit_depth", fallback),
-        "v_codec": f"{vtrack.get('format', fallback)}"
-        + f" ({vtrack['format_profile']})"
-        if vtrack.get("format_profile") else "",
+        "v_codec": f"{vtrack.get('format', gtrack.get('video_format_list', fallback))}"
+                   + (f" ({vtrack['format_profile']})" if vtrack.get("format_profile") else ""),
         "v_writing_library": truncate_string(vtrack.get("writing_library", fallback), 40),
+        "v_subsampling": vtrack.get("other_chroma_subsampling", [fallback])[-1],
     })
 
     if vtrack.get("muxing_mode") and vtrack.get("muxing_mode") == "Header stripping":
@@ -886,9 +897,9 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
             "aq-bias-strength", "aq-mode", "aq-strength", "bframes", "crf", "cutree", "no-cutree", "me",
             "no-sao", "open-gop", "psy-rd", "psy-rdoq", "qcomp", "rd", "ref", "sao", "subme", "deblock",
             "bitrate", "vbv_maxrate", "vbv_bufsize", "no-sao-non-deblock", "sao-non-deblock",
-            "no-strong-intra-smoothing", "strong-intra-smoothing",
+            "no-strong-intra-smoothing", "strong-intra-smoothing", "rc-lookahead", "merange", "zones",
             # x264 (incl. dupes, but set will dedupe it)
-            "mbtree", "no-mbtree", "aq",
+            "mbtree", "no-mbtree", "aq", "rc",  "ratetol",
         }
 
         for x in split_settings:
@@ -900,6 +911,8 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
             match split[0]:
                 case "cutree" | "no-cutree":
                     split = ["cutree", str(split[0] == "cutree")]
+                case "mbtree":
+                    split = ["mbtree", str(int(split[1]) == 1)]
                 case "sao" | "no-sao":
                     split = ["sao", str(split[0] == "sao")]
                 case "sao-non-deblock" | "no-sao-non-deblock":
@@ -909,7 +922,7 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
                 case "me":
                     if vtrack.get("format") == "HEVC":
                         split[1] = x265_me_map[int(split[1])]
-                case "aq-mode" | "aq":
+                case "aq-mode":
                     aqmode = split[1]
                     continue
                 case "aq-strength": split = ["aq", f"{aqmode}:{split[1]}"]
@@ -926,11 +939,14 @@ def source_mediainfo(filepath: str, print_mediainfo: bool = False,
                 str(k).replace("v_enc_settings_", ""): v for k, v in sorted_encset.items()
             }}
 
-        sort = pformat(print_dict, sort_dicts=False, width=100, compact=True, indent=0)
-        clip = clip.text.Text(sort[1:-1]).text.FrameNum(8) \
+        sort = pformat(print_dict, sort_dicts=False, width=100, compact=True, indent=0)[1:-1]
+        sort = sort.replace(": {", ": {\n    ").replace("'}", "'\n}").replace("                 ", "")
+
+        clip = clip.text.Text(sort).text.FrameNum(8) \
             .text.FrameProps(["_PictType", "_Matrix", "_Transfer", "_Primaries"], 9)
 
     prop_dict.update(encset_dict)
+    prop_dict.update({"Name": group or filename})
     clip = clip.std.SetFrameProps(**prop_dict)
 
     return clip
