@@ -9,13 +9,8 @@ Don't tell louis this exists though, else I'm a dead man.
 """
 from __future__ import annotations
 
-import vapoursynth as vs
-from vsexprtools import mod_x
-from vskernels import Point
-
-from .util import check_variable_resolution
-
-core = vs.core
+from vskernels import Point, Bicubic
+from vstools import check_variable_resolution, mod_x, vs
 
 __all__ = [
     'minecraftify'
@@ -34,13 +29,13 @@ def minecraftify(clip: vs.VideoNode, div: float = 64.0, mod: int | None = None)
 
     :return:        A Minecraft.
     """
-    check_variable_resolution(clip, "minecraftify")
+    check_variable_resolution(clip, minecraftify)
 
     ow, oh = round(clip.width/div), round(clip.height/div)
 
     if mod is not None:
         ow, oh = mod_x(ow, mod), mod_x(oh, mod)
 
-    i444 = core.resize.Bicubic(clip, format=vs.YUV444PS)
-    down = Point().scale(i444, ow, oh)
-    return Point().scale(down, clip.width, clip.height)
+    i444 = Bicubic.resample(clip, vs.YUV444PS)
+    down = Point.scale(i444, ow, oh)
+    return Point.scale(down, clip.width, clip.height)
